==> cohesity_management_sdk-1.6.10.tar.gz: cohesity_management_sdk-1.6.10/cohesity_management_sdk/models_v2/recovery_action_enum.py <==
# -*- coding: utf-8 -*-

class RecoveryActionEnum(object):

    """Implementation of the 'RecoveryAction' enum.

    Specifies the type of recover action.

    Attributes:
        RECOVERVMS: TODO: type description here.
        RECOVERFILES: TODO: type description here.
        INSTANTVOLUMEMOUNT: TODO: type description here.
        RECOVERVMDISKS: TODO: type description here.
        RECOVERVAPPS: TODO: type description here.
        RECOVERVAPPTEMPLATES: TODO: type description here.
        RECOVERRDS: TODO: type description here.
        RECOVERAPPS: TODO: type description here.
        RECOVERNASVOLUME: TODO: type description here.
        RECOVERPHYSICALVOLUMES: TODO: type description here.
        RECOVERSYSTEM: TODO: type description here.
        CLONEAPPVIEW: TODO: type description here.
        RECOVERSANVOLUMES: TODO: type description here.
        RECOVERMAILBOX: TODO: type description here.
        RECOVERONEDRIVE: TODO: type description here.
        RECOVERSHAREPOINT: TODO: type description here.
        RECOVERPUBLICFOLDERS: TODO: type description here.
        RECOVERNAMESPACES: TODO: type description here.
        RECOVEROBJECTS: TODO: type description here.
        DOWNLOADFILESANDFOLDERS: TODO: type description here.

    """

    RECOVERVMS = 'RecoverVMs'

    RECOVERFILES = 'RecoverFiles'

    INSTANTVOLUMEMOUNT = 'InstantVolumeMount'

    RECOVERVMDISKS = 'RecoverVmDisks'

    RECOVERVAPPS = 'RecoverVApps'

    RECOVERVAPPTEMPLATES = 'RecoverVAppTemplates'

    RECOVERRDS = 'RecoverRDS'

    RECOVERAPPS = 'RecoverApps'

    RECOVERNASVOLUME = 'RecoverNasVolume'

    RECOVERPHYSICALVOLUMES = 'RecoverPhysicalVolumes'

    RECOVERSYSTEM = 'RecoverSystem'

    CLONEAPPVIEW = 'CloneAppView'

    RECOVERSANVOLUMES = 'RecoverSanVolumes'

    RECOVERMAILBOX = 'RecoverMailbox'

    RECOVERONEDRIVE = 'RecoverOneDrive'

    RECOVERSHAREPOINT = 'RecoverSharePoint'

    RECOVERPUBLICFOLDERS = 'RecoverPublicFolders'

    RECOVERNAMESPACES = 'RecoverNamespaces'

    RECOVEROBJECTS = 'RecoverObjects'

    DOWNLOADFILESANDFOLDERS = 'DownloadFilesAndFolders'

==> cohesity_management_sdk-1.6.15.tar.gz: cohesity_management_sdk-1.6.15/cohesity_management_sdk/models_v2/recovery_action_enum.py <==
# -*- coding: utf-8 -*-

class RecoveryActionEnum(object):

    """Implementation of the 'RecoveryAction' enum.

    Specifies the type of recover action.

    Attributes:
        RECOVERVMS: TODO: type description here.
        RECOVERFILES: TODO: type description here.
        INSTANTVOLUMEMOUNT: TODO: type description here.
        RECOVERVMDISKS: TODO: type description here.
        RECOVERVAPPS: TODO: type description here.
        RECOVERVAPPTEMPLATES: TODO: type description here.
        RECOVERRDS: TODO: type description here.
        RECOVERAURORA: TODO: type description here.
        RECOVERAPPS: TODO: type description here.
        RECOVERNASVOLUME: TODO: type description here.
        RECOVERPHYSICALVOLUMES: TODO: type description here.
        RECOVERSYSTEM: TODO: type description here.
        CLONEAPPVIEW: TODO: type description here.
        RECOVERSANVOLUMES: TODO: type description here.
        RECOVERMAILBOX: TODO: type description here.
        RECOVERONEDRIVE: TODO: type description here.
        RECOVERSHAREPOINT: TODO: type description here.
        RECOVERPUBLICFOLDERS: TODO: type description here.
        RECOVERMSGROUP: TODO: type description here.
        RECOVERMSTEAM: TODO: type description here.
        CONVERTTOPST: TODO: type description here.
        RECOVERNAMESPACES: TODO: type description here.
        RECOVEROBJECTS: TODO: type description here.
        DOWNLOADFILESANDFOLDERS: TODO: type description here.

    """

    RECOVERVMS = 'RecoverVMs'

    RECOVERFILES = 'RecoverFiles'

    INSTANTVOLUMEMOUNT = 'InstantVolumeMount'

    RECOVERVMDISKS = 'RecoverVmDisks'

    RECOVERVAPPS = 'RecoverVApps'

    RECOVERVAPPTEMPLATES = 'RecoverVAppTemplates'

    RECOVERRDS = 'RecoverRDS'

    RECOVERAURORA = 'RecoverAurora'

    RECOVERAPPS = 'RecoverApps'

    RECOVERNASVOLUME = 'RecoverNasVolume'

    RECOVERPHYSICALVOLUMES = 'RecoverPhysicalVolumes'

    RECOVERSYSTEM = 'RecoverSystem'

    CLONEAPPVIEW = 'CloneAppView'

    RECOVERSANVOLUMES = 'RecoverSanVolumes'

    RECOVERMAILBOX = 'RecoverMailbox'

    RECOVERONEDRIVE = 'RecoverOneDrive'

    RECOVERSHAREPOINT = 'RecoverSharePoint'

    RECOVERPUBLICFOLDERS = 'RecoverPublicFolders'

    RECOVERMSGROUP = 'RecoverMsGroup'

    RECOVERMSTEAM = 'RecoverMsTeam'

    CONVERTTOPST = 'ConvertToPst'

    RECOVERNAMESPACES = 'RecoverNamespaces'

    RECOVEROBJECTS = 'RecoverObjects'

    DOWNLOADFILESANDFOLDERS = 'DownloadFilesAndFolders'
